export interface DayjsLocale {
    name: string;
    weekdays?: string[];
    months?: string[];
    weekStart?: number;
    weekdaysShort?: string[];
    monthsShort?: string[];
    weekdaysMin?: string[];
    ordinal?: (n: number) => number | string;
    formats: Partial<{
        LT: string;
        LTS: string;
        L: string;
        LL: string;
        LLL: string;
        LLLL: string;
    }>;
    relativeTime: Partial<{
        future: string;
        past: string;
        s: string;
        m: string;
        mm: string;
        h: string;
        hh: string;
        d: string;
        dd: string;
        M: string;
        MM: string;
        y: string;
        yy: string;
    }>;
}
export interface AntdLocale {
    locale: string;
    Pagination?: unknown;
    DatePicker?: unknown;
    TimePicker?: Record<string, unknown>;
    Calendar?: Record<string, unknown>;
    Table?: unknown;
    Modal?: unknown;
    Popconfirm?: unknown;
    Transfer?: Partial<unknown>;
    Select?: Record<string, unknown>;
    Upload?: unknown;
    Empty?: unknown;
    global?: Record<string, unknown>;
    PageHeader?: {
        back: string;
    };
    Icon?: Record<string, unknown>;
    Text?: {
        edit?: unknown;
        copy?: unknown;
        copied?: unknown;
        expand?: unknown;
    };
    Form?: {
        optional?: string;
        defaultValidateMessages: unknown;
    };
    Image?: {
        preview: string;
    };
}
export declare type LocaleDirection = 'rtl' | 'ltr';
export interface LocaleConfigOption {
    caption: string;
    direction?: LocaleDirection;
    antdLocale?: AntdLocale;
    dayjsLocale?: DayjsLocale;
    messages?: Record<string, string>;
}
export interface LocaleConfig extends LocaleConfigOption {
    messages: Record<string, string>;
    direction: LocaleDirection;
}
export declare class I18nStore {
    static LOCALE_STORAGE_KEY: string;
    localeConfigs: {
        [locale: string]: LocaleConfig;
    };
    currentLocale: string;
    private storage;
    constructor(localeConfigOptions: Record<string, LocaleConfigOption>, defaultLocale: string);
    private setLocaleConfigs;
    mergeMessages: (locale: string, messages: Record<string, string>) => void;
    setCurrentLocale: (locale: string) => void;
    get currentMessages(): Readonly<Record<string, string>>;
}
